==> bootstrap-iconpicker-1.8.1.tgz: package/README.md <==
[![Build Status](https://travis-ci.org/victor-valencia/bootstrap-iconpicker.svg?branch=master)](https://travis-ci.org/victor-valencia/bootstrap-iconpicker)
[![Code Climate](https://codeclimate.com/github/victor-valencia/bootstrap-iconpicker/badges/gpa.svg)](https://codeclimate.com/github/victor-valencia/bootstrap-iconpicker)
[![Bower](http://img.shields.io/bower/v/bootstrap-iconpicker.svg)](http://bower.io/search/?q=bootstrap-iconpicker)
[![Tag](http://img.shields.io/github/tag/victor-valencia/bootstrap-iconpicker.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/tags)
[![Release](http://img.shields.io/github/release/victor-valencia/bootstrap-iconpicker.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/releases)
[![Issues](http://img.shields.io/github/issues/victor-valencia/bootstrap-iconpicker.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/issues?q=is%3Aopen)
[![Issues](http://img.shields.io/badge/license-MIT-red.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/blob/master/LICENSE)

# [Bootstrap-Iconpicker v1.8.0](http://victor-valencia.github.io/bootstrap-iconpicker)
![Iconpicker](bootstrap-iconpicker.png)

A simple iconpicker for Bootstrap 3.x.

Please note that this project is for [Bootstrap 3.x](http://getbootstrap.com/), including Glyphicons.
Other icon fonts thats supports: [Elusive Icons](http://press.codes/downloads/elusive-icons-webfont/), [Font Awesome](http://fontawesome.io/), [Ionicons](http://ionicons.com/), [Map Icons](http://map-icons.com/), [Material Design Icons](http://zavoloklom.github.io/material-design-iconic-font/), [Octicons](https://octicons.github.com/), [Typicons](http://typicons.com), [Weather Icons](http://erikflowers.github.io/weather-icons/).

## Table of contents
- [Quick start](#quick-start)
- [Documentation and live examples](#documentation-and-live-examples)
- [Bugs and feature requests](#bugs-and-feature-requests)
- [Changelog](#changelog)
- [Versioning](#versioning)
- [Author](#author)
- [Contributors](#contributors)
- [License](#license)

## Quick start

Three quick start options are available:

- Download the latest release: [![Tag](http://img.shields.io/github/release/victor-valencia/bootstrap-iconpicker.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/v1.8.0.zip).
- Clone the repo: `git clone https://github.com/victor-valencia/bootstrap-iconpicker.git`.
- Install with [Bower](http://bower.io): `bower install bootstrap-iconpicker`.

### What's included
Within the download you'll find the following directories and files, logically grouping common assets and providing both compiled and minified variations. You'll see something like this:

```
bootstrap-iconpicker/
├── css/
│   ├── bootstrap-iconpicker.css
│   ├── bootstrap-iconpicker.min.css
├── js/
│   ├── bootstrap-iconpicker.js
│   ├── bootstrap-iconpicker.min.js
│   ├── iconset/
│       ├── iconset-all.min.js
│       ├── iconset-elusiveicon-2.0.0.js
│       ├── iconset-elusiveicon-2.0.0.min.js
│       ├── iconset-fontawesome-4.0.0.js
│       ├── iconset-fontawesome-4.0.0.min.js
│       ├── iconset-fontawesome-4.1.0.js
│       ├── iconset-fontawesome-4.1.0.min.js
│       ├── iconset-fontawesome-4.2.0.js
│       ├── iconset-fontawesome-4.2.0.min.js
│       ├── iconset-fontawesome-4.3.0.js
│       ├── iconset-fontawesome-4.3.0.min.js
│       ├── iconset-fontawesome-4.4.0.js
│       ├── iconset-fontawesome-4.4.0.min.js
│       ├── iconset-fontawesome-4.5.0.js
│       ├── iconset-fontawesome-4.5.0.min.js
│       ├── iconset-fontawesome-4.6.0.js
│       ├── iconset-fontawesome-4.6.0.min.js
│       ├── iconset-fontawesome-4.7.0.js
│       ├── iconset-fontawesome-4.7.0.min.js
│       ├── iconset-glyphicon.js
│       ├── iconset-glyphicon.min.js
│       ├── iconset-ionicon-1.5.2.js
│       ├── iconset-ionicon-1.5.2.min.js
│       ├── iconset-mapicon-2.1.0.js
│       ├── iconset-mapicon-2.1.0.min.js
│       ├── iconset-materialdesign-1.1.1.js
│       ├── iconset-materialdesign-1.1.1.min.js
│       ├── iconset-octicon-2.1.2.js
│       ├── iconset-octicon-2.1.2.min.js
│       ├── iconset-typicon-2.0.6.js
│       ├── iconset-typicon-2.0.6.min.js
│       ├── iconset-weathericon-1.2.0.js
│       └── iconset-weathericon-1.2.0.min.js
```

We provide compiled CSS and JS (`bootstrap-iconpicker.*`), as well as compiled and minified CSS and JS (`bootstrap-iconpicker.min.*`).

## Documentation and live examples
See documentation and live examples here: [http://victor-valencia.github.io/bootstrap-iconpicker](http://victor-valencia.github.io/bootstrap-iconpicker)

## Bugs and feature requests
Have a bug or a feature request? [Please open a new issue](https://github.com/victor-valencia/bootstrap-iconpicker/issues). Before opening any issue, please search for existing issues and read the [Issue Guidelines](https://github.com/necolas/issue-guidelines), written by [Nicolas Gallagher](https://github.com/necolas/).
You may use [this JSFiddle](http://jsfiddle.net/victor_valencia/y1q541ar/) as a template for your bug reports.

## Changelog
- [![v1.8.0](http://img.shields.io/badge/zip-v1.8.0-blue.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/v1.8.0.zip).
    - Fix for case, when there are no icons, and count is displayed, as '1 - 0 of 0 '. @[joews](https://github.com/joews).
    - Support multiple versions (v4.3.0 @[michaelbilcot](https://github.com/michaelbilcot), v4.4.0, v4.5.0, v4.6.0 and v4.7.0) of [Font Awesome Icons](http://fontawesome.io/).
- [![v1.7.0](http://img.shields.io/badge/zip-v1.7.0-blue.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/v1.7.0.zip).
    - Support for button and div tags.
    - All `iconset` includes the empty icon value.
    - Option `rows` accepts the value 0 to indicate all rows.
    - Add options:
        - `align`
        - `header`
        - `footer`
    - Add methods:
        - `setAlign`
        - `setHeader`
        - `setFooter`
    - Support for 1 more icon fonts:
        - [Material Design Icons v1.1.1](http://zavoloklom.github.io/material-design-iconic-font/)
- [![v1.6.0](http://img.shields.io/badge/zip-v1.6.0-blue.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/v1.6.0.zip).
    - Restructure `iconset` configuration.
    - Option `iconset` accepts `String` and `Object` (Limit your `iconset` option).
    - Add options:
        - `arrowPrevIconClass`
        - `arrowNextIconClass`
        - `labelHeader`
        - `labelFooter`
    - Add methods:
        - `setArrowClass`
        - `setArrowPrevIconClass`
        - `setArrowNextIconClass`
        - `setCols`
        - `setIconset`
        - `setLabelHeader`
        - `setLabelFooter`
        - `setPlacement`
        - `setRows`
        - `setSearch`
        - `setSearchText`
        - `setSelectedClass`
        - `setUnselectedClass`
    - Support for 6 more icon fonts:
        - [Elusive Icons v2.0.0](http://press.codes/downloads/elusive-icons-webfont/)
        - [Ionicons v1.5.2](http://ionicons.com/)
        - [Map Icons v2.1.0](http://map-icons.com/)
        - [Octicons v2.1.2](https://octicons.github.com/)
        - [Typicons v2.0.6](http://typicons.com)
        - [Weather Icons v1.2.0](http://erikflowers.github.io/weather-icons/)
- [![v1.5.0](http://img.shields.io/badge/zip-v1.5.0-blue.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/v1.5.0.zip).
    - Add search field.
- [![v1.4.0](http://img.shields.io/badge/zip-v1.4.0-blue.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/v1.4.0.zip).
    - Support for customization of the component.
- [![v1.3.1](http://img.shields.io/badge/zip-v1.3.1-blue.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/v1.3.1.zip).
    - Bind `body` `click` to solve issues for ajax loaded pages. @[crlcu](https://github.com/crlcu)
- [![v1.3.0](http://img.shields.io/badge/zip-v1.3.0-blue.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/v1.3.0.zip).
    - Support multiple versions (v4.0.0, v4.1.0, v4.2.0) of [Font Awesome Icons](http://fontawesome.io/).
- [![v1.2.1](http://img.shields.io/badge/zip-v1.2.1-blue.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/v1.2.1.zip).
    - Add `.iconpicker-popover` class. @[jwhitfieldseed](https://github.com/jwhitfieldseed)
- [![v1.2.0](http://img.shields.io/badge/zip-v1.2.0-blue.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/v1.2.0.zip).
    - Add the method `setIcon`.
- [![v1.1.0](http://img.shields.io/badge/zip-v1.1.0-blue.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/v1.1.0.zip).
    - Dispatch `change` event when an iconpicker is changed. @[promatik](https://github.com/promatik)
- [![v1.0.1](http://img.shields.io/badge/zip-v1.0.1-blue.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/v1.0.1.zip).
    - Reducing the size of the source file.
- [![v1.0.0](http://img.shields.io/badge/zip-v1.0.0-blue.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/1.0.0.zip).
    - Version initial.

## Versioning
For transparency into our release cycle and in striving to maintain backward compatibility, Bootstrap-Iconpicker is maintained under [the Semantic Versioning guidelines](http://semver.org/). Sometimes we screw up, but we'll adhere to those rules whenever possible.

Releases will be numbered with the following format:

`<major>.<minor>.<patch>`

And constructed with the following guidelines:

- Breaking backward compatibility **bumps the major** while resetting minor and patch
- New additions without breaking backward compatibility **bumps the minor** while resetting the patch
- Bug fixes and misc changes **bumps only the patch**

For more information on SemVer, please visit <http://semver.org/>.

## Author
@[victor-valencia](https://github.com/victor-valencia)

## Contributors
@[victor-valencia](https://github.com/victor-valencia), @[promatik](https://github.com/promatik), @[jwhitfieldseed](https://github.com/jwhitfieldseed), @[crlcu](https://github.com/crlcu), @[michaelbilcot](https://github.com/michaelbilcot), @[joews](https://github.com/joews)

## License
Licensed under [the MIT license](LICENSE).

==> bootstrap-iconpicker-1.8.2.tgz: package/README.md <==
[![Build Status](https://travis-ci.org/victor-valencia/bootstrap-iconpicker.svg?branch=master)](https://travis-ci.org/victor-valencia/bootstrap-iconpicker)
[![Code Climate](https://codeclimate.com/github/victor-valencia/bootstrap-iconpicker/badges/gpa.svg)](https://codeclimate.com/github/victor-valencia/bootstrap-iconpicker)
[![Bower](http://img.shields.io/bower/v/bootstrap-iconpicker.svg)](http://bower.io/search/?q=bootstrap-iconpicker)
[![Tag](http://img.shields.io/github/tag/victor-valencia/bootstrap-iconpicker.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/tags)
[![Release](http://img.shields.io/github/release/victor-valencia/bootstrap-iconpicker.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/releases)
[![Issues](http://img.shields.io/github/issues/victor-valencia/bootstrap-iconpicker.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/issues?q=is%3Aopen)
[![Issues](http://img.shields.io/badge/license-MIT-red.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/blob/master/LICENSE)

# [Bootstrap-Iconpicker v1.8.2](http://victor-valencia.github.io/bootstrap-iconpicker)
![Iconpicker](bootstrap-iconpicker.png)

A simple iconpicker for Bootstrap 3.x.

Please note that this project is for [Bootstrap 3.x](http://getbootstrap.com/), including Glyphicons.
Other icon fonts thats supports: [Elusive Icons](http://press.codes/downloads/elusive-icons-webfont/), [Font Awesome](http://fontawesome.io/), [Ionicons](http://ionicons.com/), [Map Icons](http://map-icons.com/), [Material Design Icons](http://zavoloklom.github.io/material-design-iconic-font/), [Octicons](https://octicons.github.com/), [Typicons](http://typicons.com), [Weather Icons](http://erikflowers.github.io/weather-icons/).

## Table of contents
- [Quick start](#quick-start)
- [Documentation and live examples](#documentation-and-live-examples)
- [Bugs and feature requests](#bugs-and-feature-requests)
- [Changelog](#changelog)
- [Versioning](#versioning)
- [Author](#author)
- [Contributors](#contributors)
- [License](#license)

## Quick start

Three quick start options are available:

- Download the latest release: [![Tag](http://img.shields.io/github/release/victor-valencia/bootstrap-iconpicker.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/v1.8.2.zip).
- Clone the repo: `git clone https://github.com/victor-valencia/bootstrap-iconpicker.git`.
- Install with [Bower](http://bower.io): `bower install bootstrap-iconpicker`.
- Install with [NPM](https://www.npmjs.com): `npm install bootstrap-iconpicker`.

### What's included
Within the download you'll find the following directories and files, logically grouping common assets and providing both compiled and minified variations. You'll see something like this:

```
bootstrap-iconpicker/
├── css/
│   ├── bootstrap-iconpicker.css
│   ├── bootstrap-iconpicker.min.css
├── js/
│   ├── bootstrap-iconpicker.js
│   ├── bootstrap-iconpicker.min.js
│   ├── iconset/
│       ├── iconset-all.min.js
│       ├── iconset-elusiveicon-2.0.0.js
│       ├── iconset-elusiveicon-2.0.0.min.js
│       ├── iconset-fontawesome-4.0.0.js
│       ├── iconset-fontawesome-4.0.0.min.js
│       ├── iconset-fontawesome-4.1.0.js
│       ├── iconset-fontawesome-4.1.0.min.js
│       ├── iconset-fontawesome-4.2.0.js
│       ├── iconset-fontawesome-4.2.0.min.js
│       ├── iconset-fontawesome-4.3.0.js
│       ├── iconset-fontawesome-4.3.0.min.js
│       ├── iconset-fontawesome-4.4.0.js
│       ├── iconset-fontawesome-4.4.0.min.js
│       ├── iconset-fontawesome-4.5.0.js
│       ├── iconset-fontawesome-4.5.0.min.js
│       ├── iconset-fontawesome-4.6.0.js
│       ├── iconset-fontawesome-4.6.0.min.js
│       ├── iconset-fontawesome-4.7.0.js
│       ├── iconset-fontawesome-4.7.0.min.js
│       ├── iconset-glyphicon.js
│       ├── iconset-glyphicon.min.js
│       ├── iconset-ionicon-1.5.2.js
│       ├── iconset-ionicon-1.5.2.min.js
│       ├── iconset-mapicon-2.1.0.js
│       ├── iconset-mapicon-2.1.0.min.js
│       ├── iconset-materialdesign-1.1.1.js
│       ├── iconset-materialdesign-1.1.1.min.js
│       ├── iconset-octicon-2.1.2.js
│       ├── iconset-octicon-2.1.2.min.js
│       ├── iconset-typicon-2.0.6.js
│       ├── iconset-typicon-2.0.6.min.js
│       ├── iconset-weathericon-1.2.0.js
│       └── iconset-weathericon-1.2.0.min.js
```

We provide compiled CSS and JS (`bootstrap-iconpicker.*`), as well as compiled and minified CSS and JS (`bootstrap-iconpicker.min.*`).

## Documentation and live examples
See documentation and live examples here: [http://victor-valencia.github.io/bootstrap-iconpicker](http://victor-valencia.github.io/bootstrap-iconpicker)

## Bugs and feature requests
Have a bug or a feature request? [Please open a new issue](https://github.com/victor-valencia/bootstrap-iconpicker/issues). Before opening any issue, please search for existing issues and read the [Issue Guidelines](https://github.com/necolas/issue-guidelines), written by [Nicolas Gallagher](https://github.com/necolas/).
You may use [this JSFiddle](http://jsfiddle.net/victor_valencia/y1q541ar/) as a template for your bug reports.

## Changelog
- [![v1.8.2](http://img.shields.io/badge/zip-v1.8.2-blue.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/v1.8.2.zip).    
    - Fix navigation to invalid pages.
    - Filling search/hidden inputs. @[s-belichenko-sold](https://github.com/s-belichenko-sold)
    - Search and filter case insensitive. @[mahmoud-asadi](https://github.com/mahmoud-asadi)
    - Support for [Bootstrap 3.3.7](http://getbootstrap.com/).
    - Update license to [MIT](https://github.com/victor-valencia/bootstrap-iconpicker/blob/master/LICENSE).
- [![v1.8.1](http://img.shields.io/badge/zip-v1.8.1-blue.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/v1.8.1.zip).
    - Support for [NPM](https://www.npmjs.com) install.
- [![v1.8.0](http://img.shields.io/badge/zip-v1.8.0-blue.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/v1.8.0.zip).
    - Fix for case, when there are no icons, and count is displayed, as '1 - 0 of 0 '. @[joews](https://github.com/joews).
    - Support for multiple versions (v4.3.0 @[michaelbilcot](https://github.com/michaelbilcot), v4.4.0, v4.5.0, v4.6.0 and v4.7.0) of [Font Awesome Icons](http://fontawesome.io/).
- [![v1.7.0](http://img.shields.io/badge/zip-v1.7.0-blue.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/v1.7.0.zip).
    - Support for button and div tags.
    - All `iconset` includes the empty icon value.
    - Option `rows` accepts the value 0 to indicate all rows.
    - Add options:
        - `align`
        - `header`
        - `footer`
    - Add methods:
        - `setAlign`
        - `setHeader`
        - `setFooter`
    - Support for 1 more icon fonts:
        - [Material Design Icons v1.1.1](http://zavoloklom.github.io/material-design-iconic-font/)
- [![v1.6.0](http://img.shields.io/badge/zip-v1.6.0-blue.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/v1.6.0.zip).
    - Restructure `iconset` configuration.
    - Option `iconset` accepts `String` and `Object` (Limit your `iconset` option).
    - Add options:
        - `arrowPrevIconClass`
        - `arrowNextIconClass`
        - `labelHeader`
        - `labelFooter`
    - Add methods:
        - `setArrowClass`
        - `setArrowPrevIconClass`
        - `setArrowNextIconClass`
        - `setCols`
        - `setIconset`
        - `setLabelHeader`
        - `setLabelFooter`
        - `setPlacement`
        - `setRows`
        - `setSearch`
        - `setSearchText`
        - `setSelectedClass`
        - `setUnselectedClass`
    - Support for 6 more icon fonts:
        - [Elusive Icons v2.0.0](http://press.codes/downloads/elusive-icons-webfont/)
        - [Ionicons v1.5.2](http://ionicons.com/)
        - [Map Icons v2.1.0](http://map-icons.com/)
        - [Octicons v2.1.2](https://octicons.github.com/)
        - [Typicons v2.0.6](http://typicons.com)
        - [Weather Icons v1.2.0](http://erikflowers.github.io/weather-icons/)
- [![v1.5.0](http://img.shields.io/badge/zip-v1.5.0-blue.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/v1.5.0.zip).
    - Add search field.
- [![v1.4.0](http://img.shields.io/badge/zip-v1.4.0-blue.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/v1.4.0.zip).
    - Support for customization of the component.
- [![v1.3.1](http://img.shields.io/badge/zip-v1.3.1-blue.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/v1.3.1.zip).
    - Bind `body` `click` to solve issues for ajax loaded pages. @[crlcu](https://github.com/crlcu)
- [![v1.3.0](http://img.shields.io/badge/zip-v1.3.0-blue.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/v1.3.0.zip).
    - Support for multiple versions (v4.0.0, v4.1.0, v4.2.0) of [Font Awesome Icons](http://fontawesome.io/).
- [![v1.2.1](http://img.shields.io/badge/zip-v1.2.1-blue.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/v1.2.1.zip).
    - Add `.iconpicker-popover` class. @[jwhitfieldseed](https://github.com/jwhitfieldseed)
- [![v1.2.0](http://img.shields.io/badge/zip-v1.2.0-blue.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/v1.2.0.zip).
    - Add the method `setIcon`.
- [![v1.1.0](http://img.shields.io/badge/zip-v1.1.0-blue.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/v1.1.0.zip).
    - Dispatch `change` event when an iconpicker is changed. @[promatik](https://github.com/promatik)
- [![v1.0.1](http://img.shields.io/badge/zip-v1.0.1-blue.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/v1.0.1.zip).
    - Reducing the size of the source file.
- [![v1.0.0](http://img.shields.io/badge/zip-v1.0.0-blue.svg)](https://github.com/victor-valencia/bootstrap-iconpicker/archive/1.0.0.zip).
    - Version initial.

## Versioning
For transparency into our release cycle and in striving to maintain backward compatibility, Bootstrap-Iconpicker is maintained under [the Semantic Versioning guidelines](http://semver.org/). Sometimes we screw up, but we'll adhere to those rules whenever possible.

Releases will be numbered with the following format:

`<major>.<minor>.<patch>`

And constructed with the following guidelines:

- Breaking backward compatibility **bumps the major** while resetting minor and patch
- New additions without breaking backward compatibility **bumps the minor** while resetting the patch
- Bug fixes and misc changes **bumps only the patch**

For more information on SemVer, please visit <http://semver.org/>.

## Author
@[victor-valencia](https://github.com/victor-valencia)

## Contributors
@[victor-valencia](https://github.com/victor-valencia), @[promatik](https://github.com/promatik), @[jwhitfieldseed](https://github.com/jwhitfieldseed), @[crlcu](https://github.com/crlcu), @[michaelbilcot](https://github.com/michaelbilcot), @[joews](https://github.com/joews), @[s-belichenko-sold](https://github.com/s-belichenko-sold), @[mahmoud-asadi](https://github.com/mahmoud-asadi)

## License
Licensed under [the MIT license](LICENSE).
